#
# spec file for package python-portalocker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-portalocker
Version:        2.8.2
Release:        1.5
Summary:        Locking library for Python
License:        Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/WoLpH/portalocker
Source:         https://github.com/WoLpH/portalocker/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 3.4.0}
BuildRequires:  %{python_module setuptools >= 38.3.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-redis
BuildArch:      noarch
%python_subpackages

%description
Portalocker is a library to provide an API to file locking.

On Linux and Unix systems, the locks are advisory by default. By
specifying the `-o mand` option to the mount command, it is possible
to enable mandatory file locking on Linux. This is generally not
recommended however.

%prep
%setup -q -n portalocker-%{version}
# do not bother with benchmark and cov
rm pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Do not test redis, the optional dependency is not installed by
# default
%pytest --ignore portalocker_tests/test_redis.py

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/portalocker
%{python_sitelib}/portalocker-%{version}.dist-info

%changelog
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2.8.2:
  * Removed docs from build to fix #88 again
- update to 2.8.0:
  * Added support for Python 3.11 and 3.12
    Made the package fully ruff, pyright and mypy compliant with
    automated testsing using both tox and Github actions
* Fri May  5 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.7.0:
  * Added fail_when_locked=False support to BoundedSemaphore thanks to
    @flaviens
- 2.6.0:
  * Added fileno() support. Fixes #80 on posix systems
- 2.5.1:
  * Added clear warning when locking in non-blocking mode without
    specifying either EXCLUSIVE or SHARED mode. Fixes #77
- 2.5.0:
  * Fixed shared locks on Windows and simplified locking mechanism
- 2.4.0:
  * Added warning when trying to use a timeout in blocking mode. And
    removed deprecated testing code and checks
- 2.3.2:
  * Added semver indicator and specified needed Python release thanks
    to @rayluo v2.3.2
- 2.3.1:
  * Removed Python 2 classifier thanks to @rayluo v2.3.1
- 2.3.0:
  * enabled PEP 561 compliance v2.3.0
- 2.2.1:
  * removed debug statement v2.2.1
- 2.2.0:
  * updated travis location
- 2.1.0:
  * Added Redis based distributed lock which gracefully handles
    connection loss and dying applications. Added full type hinting
    support. Fixed bug where the file handle was not always explicitly
    closed with errors
- v2.0.0:
  * Removed support for old Python versions. Versions 3.5 and above
    are supported. Added BoundedSemaphore class
- 1.7.1:
  * removed tests from wheel file
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Jun  3 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.7.0
  * Fix ResourceWarning unclosed file if LockException is raised
- from v1.6.0
  * Fixed unlocking bug on Windows
* Wed Mar 18 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.5.2
  * Allow for development setuptools
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.1:
  * no upstream changelog
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.0:
  * No upstream changelog
- Switch to github tarball to include tests
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.0:
  * no upstream changelog
- Drop patch portalocker-1.2.1-old-Sphinx.patch
* Fri May 18 2018 jengelh@inai.de
- Clear filler wording from description.
* Thu May 17 2018 mcepl@suse.com
- Fix specfile name
* Thu May 17 2018 mcepl@suse.com
- Initial packaging effort
